File management routines
========================

DevNullFilelikeObject
---------------------

A file-like object that will dispose of your content.

.. autoclass:: satella.files.DevNullFilelikeObject
    :members:

safe_listdir
------------

.. autofunction:: satella.os.safe_listdir

read_lines
----------

.. autofunction:: satella.files.read_lines

read_re_sub_and_write
---------------------

.. autofunction:: satella.files.read_re_sub_and_write

find_files
----------

.. autofunction:: satella.files.find_files

split
-----

.. autofuction:: satella.files.split

read_in_file
------------

.. autofunction:: satella.files.read_in_file

write_to_file
-------------

.. autofunction:: satella.files.write_to_file

write_out_file_if_different
---------------------------

.. autofunction:: satella.files.write_out_file_if_different

AutoflushFile
-------------

.. autoclass:: satella.files.AutoflushFile
    :members:
